# History file 'ran-net.h' to generate a 2-D representation of the
# Laguerr random medium and to calculate first arrival travel times
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# The propagation velocities are similar to the 2-D representation of
# the Laguerr random medium displayed in Figure 8 of paper
#     Klimes, L. (1997): Correlation functions of random media.
#         In: Seismic Waves in Complex 3-D Structures, Report 6.
#         Department of Geophysics, Charles University, Prague,
#         pp.25-40,
# but the Gaussian corrrelation length is twice enlarged to aG=0.010.

# Input files required:
 #chk.pl: "net/"     "net.fs2"       # 2-D forward stars of 'net.for'
 #chk.pl: "net/ran/" "ran-net.dat"   # data for program 'net.for'
 #chk.pl: "net/ran/" "ran-src.dat"   # source coordinates
 #chk.pl: "forms/"   "atan2.cal"

# Grid dimensions:
  N1=501  N2=501  D1=0.002  D2=0.002  O1=0.000  O2=0.000

# Laguerr correlation function (data for GRDRAN2D):
  CTYPE='D'  POWERN=-0.2  ACORG=0.010  ACOR=

# Particular pseudo-random representation:
  ISEED=-13

# Velocities between 0.0 and 2.0, with mean value of 1.0 (for GRDRAN2D):
  DSD=0.500  VMEAN=1.000  DEVMAX=1.000  DEVEXP=2.

# Dimensions of the figures (unimportant data for GRDPS):
  HSIZE=16.032  HOFFSET=2.484

# Colours to plot velocities (data for GRDPS):
  VCIRC=2.000     VREF=1.000  CREF=.166667 # Colour scale

# List of input and output filenames for the NET program:
  NET='ran-net.dat'

# Numerical parameters for the NET program (setting TTT mode):
  NFSMAX=-1

# Generating a representation of the random medium:
  grdran2d: 'ran-net.h' 'ran-vel.out' /

# Plotting the representation of the random medium:
  grdps: 'ran-net.h' 'ran-vel.out' 'ran-vel.ps' /

# Calculating first-arrival travel times:
  net: 'ran-net.h' /

# Plotting first-arrival travel times ("wavefronts"):
  VCIRC=0.050     VREF=0.000  CREF=.166667 # Colour scale
  grdps: 'ran-net.h' 'ran-tt.out' 'ran-tt.ps' /

# Plotting directions of propagation:
  VCIRC=6.283185  VREF=0.000  CREF=.166667 # Colour scale
  grdcal: 'ran-net.h' 'atan2' 'ran-p1.out' 'ran-p2.out' 'ran-dir.tmp' /
  grdps:  'ran-net.h' 'ran-dir.tmp' 'ran-dir.ps' /


# Checking the accuracy of travel times (disabled by default):
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Input files required:
 #chk.pl: "net/ran/" "ran-net2.dat"  # Input data file for 'net.for'
                                     # for the check of accuracy
 #chk.pl: "forms/"   "absdif.cal"
 #chk.pl: "forms/"   "reldif.cal"

# Changing input and output filenames for the NET program:
  NET='ran-net2.dat'

# Grid dimensions for the test of accuracy:
# N1=1001  N2=1001  D1=0.001  D2=0.001  O1=0.000  O2=0.000
# Above grid requires MRAM=4008004, at the least, in 'ram.inc'.
# It is thus reduced to
# N1=999  N2=999  D1=0.001002  D2=0.001002  O1=0.000002  O2=0.000002
# to fit into the default of MRAM=4000000.

# Calculating first-arrival travel times on the denser grid:
  N1NEW=999  N2NEW=999  D1NEW=0.001002  D2NEW=0.001002
                        O1NEW=0.000002  O2NEW=0.000002
 #grdnew: 'ran-net.h' 'ran-vel.out' 'ran-vel.tmp' /
  N1=999  N2=999  D1=0.001002  D2=0.001002  O1=0.000002  O2=0.000002
 #net:    'ran-net.h' /
  N1NEW=501  N2NEW=501  D1NEW=0.002  D2NEW=0.002  O1NEW=0.000  O2NEW=0.000
 #grdnew: 'ran-net.h' 'ran-tt.tmp' 'ran-tt2.out' /

# Restoring original grid dimensions:
  N1=501  N2=501  D1=0.002  D2=0.002  O1=0.000  O2=0.000
  N1NEW=  N2NEW=  D1NEW=  D2NEW=  O1NEW=  O2NEW=

# Colours to plot absolute travel-time errors:
  VCIRC=0.006  VREF=0.000  CREF=.166667
 #grdcal: 'ran-net.h' 'absdif' 'ran-tt.out' 'ran-tt2.out' 'ran-err.out' /
 #grdps:  'ran-net.h' 'ran-err.out' 'ran-err.ps' /

# Colours to plot relative travel-time errors:
  VCIRC=0.012  VREF=0.000  CREF=.166667
 #grdcal: 'ran-net.h' 'reldif' 'ran-tt.out' 'ran-tt2.out' 'ran-rel.out' /
 #grdps:  'ran-net.h' 'ran-rel.out' 'ran-rel.ps' /

# ======================================================================

# Temporary files (may be deleted):
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# '*.tmp'

# List of output files:
# ~~~~~~~~~~~~~~~~~~~~~
# Output data files:
#     'ran-vel.out' Propagation velocities on grid 501*501
#     'ran-tt.out'  First arrival travel times on grid 501*501
#     'ran-p1.out', 'ran-p2.out'   Slowness-vector components
# PostScript figures are in files:
#     'ran-vel.ps'  Propagation velocities on grid 501*501
#     'ran-tt.ps'   First arrival travel times on grid 501*501
#     'ran-dir.ps'  Directions of propagation on grid 501*501

# List of output files of the accuracy test:
# ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
# Output data files:
#     'ran-tt2.out' First arrival travel times on the original grid,
#                   calculated on the denser grid.
#     'ran-err.out' Absolute value of travel-time differences between
#                   'ran-tt.out' and 'ran-tt2.out'
#     'ran-rel.out' Relative travel-time differences between
#                   'ran-tt.out' and 'ran-tt2.out'
# PostScript figures are in files:
#     'ran-err.ps'  Absolute differences of first arrival travel times
#     'ran-rel.ps'  Relative differences of first arrival travel times
#
#     Colour:   Absolute  Relative
#               errors:   errors:
#       yellow    0.000     0.000
#       green     0.001     0.002
#       cyan      0.002     0.004
#       blue      0.003     0.006
#       magenta   0.004     0.008
#       red       0.005     0.010
